@@ -1,24 +1,22 @@
-import collections
 import abc
+import collections
+import configparser
+import copy
 import itertools
 import json
 import os
-import typing
-import configparser
 import textwrap
-import copy
+import typing
 from enum import auto
 
 import stringcase
 import tomlkit
-
 from ruamel import yaml
 from ruamel.yaml.comments import CommentedMap
 
 from ._tools import AutoNameEnum
 from .errors import ConfigError
 
-
 undefined = object()
 
 
@@ -221,9 +219,13 @@ class TomlConfigSerializer(BaseConfigSerializer):
                     else:
                         good = add_value(section, key, value)
                         if good:
-                            section[key].comment(prop.comment)
+                            if isinstance(value, bool):
+                                item = section.item(key)
+                            else:
+                                item = section[key]
+                            item.comment(prop.comment)
                 else:
-                    section.add(key, value)
+                    add_value(section, key, value)
 
         with open(path, 'w') as file:
             file.write(tomlkit.dumps(doc))
@@ -266,7 +268,7 @@ class ConfigProperty:
             comment=None,
             config_type=None,
             environ_name=None,
-            auto_environ=True,
+            auto_environ=False,
             name=None,
             auto_global=False,
             global_name=None,
@@ -331,7 +333,7 @@ class ConfigProperty:
                     value = self.config_type(value)
             except TypeError as err:
                 raise ConfigError(
-                    f'Expected type {self.config_type.__name__} for {value}'
+                    f'Expected type {repr(self.config_type)} for {value}'
                 ) from err
 
         return value
@@ -514,7 +516,9 @@ class Config(Nestable):
         def handle_dict(root, parent, updatable, orig):
             for key, value in root.items():
                 if not parent:
-                    prop = getattr(type(self), key)
+                    prop = getattr(type(self), key, undefined)
+                    if prop is undefined:
+                        continue
                 else:
                     prop = getattr(parent.nested_cls, key)
 
